Skip to contents

Tells you what function to use to get covariates data! Also returns information on datasets, bands or columns, and more.

Usage

covariate_helper(covariate)

Arguments

covariate

Covariate name or ID

Examples

# covariate_helper("Daily Global 5km Satellite Sea Surface Temperature (CoralTemp)")
# covariate_helper("GPW MEOW Realms")